﻿using NetTopologySuite.Geometries;
using System;
using System.Collections.Generic;
using System.Data.Entity.Spatial;
using System.Drawing;
using System.Globalization;
using System.Linq;

namespace DevartSharpMapDemo {

  public class Queries {

    private SampleHelper helper;

    public Queries(SampleHelper helper) {

      if (helper == null)
        throw new ArgumentNullException("helper");

      this.helper = helper;
    }

    public void FranceCities() {

      Console.WriteLine();
      Console.WriteLine("France cities:");

      using (var ctx =  helper.CreateModel()) {
        var cities = ctx.Cities
          .OrderBy(city => city.Name)
          .ToList();

        foreach (var city in cities)
          Console.WriteLine($"* {city.Name}: Latitude={city.Geometry.Latitude}, Longitude={city.Geometry.Longitude}");
      }
    }

    public void FindDistances() {

      Console.WriteLine();

      using (var ctx = helper.CreateModel()) {

        string fromCity = "Paris";
        var query = from city in ctx.Cities
                    join secondCity in ctx.Cities on city.Name equals fromCity
                    orderby secondCity.Name
                    select new
                    {
                      SecondCityName = secondCity.Name,
                      Distance = city.Geometry.Distance(secondCity.Geometry)
                    };
        var results = query.ToList();

        foreach (var item in results) {
          int distance = (int)Math.Round(item.Distance.GetValueOrDefault());
          Console.WriteLine($"Distance from {fromCity} to {item.SecondCityName} = {distance} km");
        }
      }
    }

  }

}
